<?php

namespace Drupal\slimmer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure example settings for this site.
 */
class SettingForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'slimmer.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'slimmer_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    \Drupal::logger('slimmer')->info('Kippensoep');

    $config = $this->config(static::SETTINGS);

    $form['slimmer_project'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Project name'),
      '#default_value' => $config->get('slimmer_project'),
    ];

    $form['slimmer_autolog'] = [
      '#type' => 'radios',
      '#title' => $this->t('Autologger enabled'),
      '#default_value' => $config->get('slimmer_autolog'),
      '#options' => [
        t('No'),
        t('Yes'),
      ],
    ];

    $form['slimmer_endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('The endpoint to post requests to'),
      '#default_value' => $config->get('slimmer_endpoint'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(static::SETTINGS)
      ->set('slimmer_project', $form_state->getValue('slimmer_project'))
      ->set('slimmer_autolog', $form_state->getValue('slimmer_autolog'))
      ->set('slimmer_endpoint', $form_state->getValue('slimmer_endpoint'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
